galgebra
========

geometric algebra/calculus modules for sympy

This package was originally written by Alan Bromborsky

Note that in the doc directory there is BookGA.pdf which is a collection of notes on 
Geometric Algebra and Calculus based of "Geometric Algebra for Physicists" by Doran and 
Lasenby and on some papers by Lasenby and Hestenes.


TODO
========

Get the library on PyPi
Get compatible with python 3
Get the docs on read the docs
Ensure functions are documented
